library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity SComp is
    Port ( DATA 	: in std_logic;
           AnB 	: in std_logic;
           LT 		: out std_logic;
           EQ 		: out std_logic;
           GT 		: out std_logic;
           CLK 	: in std_logic;
           ENABLE : in std_logic;
			  RESET	: in std_logic);
end SComp;

architecture RTL of SComp is

	signal ShiftA : unsigned(7 downto 0);		--byte shift register A
	signal ShiftB : unsigned(7 downto 0);		--byte shift register B
	

begin

ShftA:	process(DATA, CLK, AnB, RESET)
begin
	if RESET = '1' then
		ShiftA <= X"00";
	elsif (AnB = '1') and rising_edge(CLK) then
		ShiftA <= DATA & ShiftA(7 downto 1);
	end if;
end process ShftA;

ShftB:	process(DATA, CLK, AnB, RESET)
begin
	if RESET = '1' then
		ShiftB <= X"00";
	elsif (AnB = '0') and rising_edge(CLK) then
		ShiftB <= DATA & ShiftB(7 downto 1);
	end if;
end process ShftB;

Cmpr:		process(ShiftA, ShiftB, ENABLE)
begin
	if ENABLE = '1' then
		if ShiftA > ShiftB then
			GT <= '1';
			EQ <= '0';
			LT <= '0';
		elsif ShiftA = ShiftB then
			GT <= '0';
			EQ <= '1';
			LT <= '0';
		else
			GT <= '0';
			EQ <= '0';
			LT <= '1';
		end if;
	else
		GT <= '0';
		EQ <= '0';
		LT <= '0';
	end if;
end process Cmpr;

end RTL;
